# pylint: disable=C0103
from __future__ import absolute_import
import pandas as pd
import re
import sys
import unicodedata
import codecs
import xmltodict as xd
from dateutil import parser
import arrow
import gzip
import numpy as np
import string
from six import unichr

from lxml import etree
from docopt import docopt

ns1 = 'http://www.topografix.com/GPX/1/1'



def gpxtodf2(path):
    tree = etree.parse(path)
    root = tree.getroot()

    tracks = []
    lapnr = 0

    for element in root.iter():
        if element.tag == '{%s}trkseg'%ns1:
            lapnr += 1
        if element.tag == '{%s}trkpt'%ns1:
            tracks.append((lapnr,element))

    t = []
    d = []
    hr = []
    power = []
    lat = []
    cadence = []
    lon = []
    lapid = []

    for lapnr,element in tracks:
        latitude, longitude = element.values()
        lapid.append(lapnr)
        lat.append(float(latitude))
        lon.append(float(longitude))
        for child in element:
            if child.tag == '{%s}time'%ns1:
                try:
                    time = parser.parse(child.text)
                    timestamp = arrow.get(time).timestamp+arrow.get(time).microsecond/1.e6
                    t.append(timestamp)
                except KeyError:
                    t.append(np.nan)


    df = pd.DataFrame(
        {
            'TimeStamp (sec)':t,
            ' latitude':lat,
            ' longitude':lon,
            ' lapIdx':lapid,
            }
        )


    return df



#! /usr/bin/python
from __future__ import absolute_import
from __future__ import print_function
from . import rowingdata
from sys import argv

def main():
    try:
	boatFile=argv[1]
    except IndexError:
	boatFile="my1x.txt"

    print((rowingdata.boatedit(boatFile)))

    print("done")



from __future__ import absolute_import
#from setuptools import setup, find_packages
from distutils.core import setup
import setuptools

import re

def readme():
    with open('README.rst') as f:
        return f.read()

setup(name='rowingdata',
      version=re.search(
          '^__version__\s*=\s*"(.*)"',
          open('rowingdata/rowingdata.py').read(),
          re.M
      ).group(1),

      classifiers = [
          "Programming Language :: Python :: 3",
          ],

      #      python_requires='>=3.4',

      description='The rowingdata library to create colorful plots from CrewNerd, Painsled and other rowing data tools',

      long_description=readme(),

      url='',

      author='Sander Roosendaal',

      author_email='roosendaalsander@gmail.com',

      license='MIT',

      packages=['rowingdata'],
      #packages=find_packages(),

      keywords='rowing ergometer concept2',

      install_requires=[
	  'Cython',
	  'numpy',
	  'scipy',
	  'matplotlib',
	  'pandas',
	  'fitparse',
	  #          'fitparse',
	  'arrow>=1.0.2',
	  #	  'mechanize',
	  'python-dateutil',
	  'docopt',
	  'tqdm',
	  'rowingphysics>=0.2.3',
	  'iso8601',
	  'lxml',
	  'xmltodict',
	  'nose_parameterized',
	  'timezonefinder',
	  'pycairo',
	  'tk','requests'
      ],

      zip_safe=False,
      include_package_data=True,
      # relative to the rowingdata directory
      package_data={
          'testdata':[
              'crewnerddata.CSV',
              'crewnerddata.tcx',
              'example.csv',
              'painsled_desktop_example.csv',
              'RP_testdata.csv',
              'SpeedCoach2example.csv',
              'testdata.csv'
          ],
          'bin':[
              'testdata.csv',
              'crewnerddata.csv',
              'crewnerddata.tcx',
          ],
          'rigging':[
              '1x.txt',
              '2x.txt',
              '4x-.txt',
              '4-.txt',
              '4+.txt',
              '2-.txt',
              '8+.txt'
          ]
      },

#      entry_points={
#          "console_scripts": [
#              'rowingdata=rowingdata.rowingdata:main',
#              'painsledtoc2=rowingdata.painsledtoc2:main',
#              'painsledplot=rowingdata.painsledplot:main',
#              'crewnerdplot=rowingdata.crewnerdplot:main',
#              'tcxtoc2=rowingdata.tcxtoc2:main',
#              'painsled_desktop_toc2=rowingdata.painsled_desktop_toc2:main',
#              'painsledplottime=rowingdata.painsledplottime:main',
#              'painsled_desktop_plottime=rowingdata.painsled_desktop_plottime:main',
#              'crewnerdplottime=rowingdata.crewnerdplottime:main',
#              'roweredit=rowingdata.roweredit:main',
#              'copystats=rowingdata.copystats:main',
#              'tcxplot=rowingdata.tcxplot:main',
#              'tcxplottime=rowingdata.tcxplottime:main',
#              'tcxplot_nogeo=rowingdata.tcxplot_nogeo:main',
#              'tcxplottime_nogeo=rowingdata.tcxplottime_nogeo:main',
#              'speedcoachplot=rowingdata.speedcoachplot:main',
#              'speedcoachplottime=rowingdata.speedcoachplottime:main',
#              'speedcoachtoc2=rowingdata.speedcoachtoc2:main',
#              'rowproplot=rowingdata.rowproplot:main',
#              'ergdataplot=rowingdata.ergdataplot:main',
#              'ergdataplottime=rowingdata.ergdataplottime:main',
#              'ergdatatotcx=rowingdata.ergdatatotcx:main',
#              'ergstickplot=rowingdata.ergstickplot:main',
#              'ergstickplottime=rowingdata.ergstickplottime:main',
#              'ergsticktotcx=rowingdata.ergsticktotcx:main',
#              'windcorrected=rowingdata.windcorrected:main',
#              'boatedit=rowingdata.boatedit:main',
#              'rowproplottime=rowingdata.rowproplottime:main'
#          ]
#      },


)



#! /usr/bin/python
from __future__ import absolute_import
from __future__ import print_function
from . import rowingdata
from sys import argv

def main():
    readFile=argv[1]

    try:
        rowerFile=argv[2]
    except IndexError:
        rowerFile="defaultrower.txt"

    rower=rowingdata.getrower(rowerFile)

    outfile=readFile+"_o.csv"

    res=rowingdata.painsledDesktopParser(readFile)
    res.write_csv(outfile)

    row=rowingdata.rowingdata(outfile,rowtype="Indoor Rower",rower=rower)

    row.plotmeters_erg()

    print((row.allstats()))



    print(("done "+readFile))
